@@ -13,7 +13,7 @@
  *
  * @link http://exbridge.jp/
  * @author S.Tajima <tajima@exbridge.jp>
- * @version svn:$Id: xbpwController.php 613 2008-06-30 04:30:41Z tajima $
+ * @version svn:$Id: xbpwController.php 16 2008-07-10 12:10:55Z tshiro $
  * @copyright 2007-2008 Exbridge,Inc.
  */
 class xbpwController
@@ -76,7 +76,7 @@ class xbpwController
     var $_pw_disable_session = PW_DISABLE_SESSION;
 
     /** specified action name */
-    var $_pw_action = '';
+    var $_pw_action = 'default';
 
     /** instance of view processor */
     var $_pw_view = null;
@@ -476,7 +476,11 @@ class xbpwController
                 $query[] = urlencode($key) . '=' . urlencode($value);
             }
             if (count($query)>0) {
-                $path .= '?' . implode('&', $query);
+                if(!strpos($path,'?')){
+                    $path .= '?' . implode('&', $query);
+                }else{
+                    $path .= '&' . implode('&', $query);
+                }
             }
             header('Location: http://' . $_SERVER['HTTP_HOST'] . convert_uri($path));
             return PW_CONTINUE_PROCESS;
